<?php

namespace Accounting\Invoice\Forms;

use Litepie\Form\FormInterpreter;

class Invoice extends FormInterpreter
{

    /**
     * Sets the form and form elements.
     * @return null.
     */
    public static function setAttributes()
    {

        self::$urls = [
            'new' => [
                'url' => guard_url('invoice/invoice/new'),
                'method' => 'GET',
            ],
            'create' => [
                'url' => guard_url('invoice/invoice/create'),
                'method' => 'GET',
            ],
            'store' => [
                'url' => guard_url('invoice/invoice'),
                'method' => 'POST',
            ],
            'update' => [
                'url' => guard_url('invoice/invoice'),
                'method' => 'PUT',
            ],
            'list' => [
                'url' => guard_url('invoice/invoice'),
                'method' => 'GET',
            ],
            'delete' => [
                'url' => guard_url('invoice/invoice'),
                'method' => 'DELETE',
            ],
        ];
        self::$search = [
            'name' => [
                "type" => 'text',
                "label" => trans('invoice::invoice.label.name'),
                "placeholder" => trans('invoice::invoice.placeholder.name'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "4",
                "roles" => [],
            ]
        ];
        self::$orderBy = [
            'created_at' => trans('invoice::invoice.label.created_at'),
            'name' => trans('invoice::invoice.label.name'),
            'status' => trans('invoice::invoice.label.status'),
        ];
        self::$groups = [
            'main' => trans('invoice::invoice.groups.main'),
            'details' => trans('invoice::invoice.groups.details'),
            'images' => trans('invoice::invoice.groups.images'),
            'settings' => trans('invoice::invoice.groups.settings'),
        ];
        self::$list = [
            [
                'key' => "ref",
                'label' => trans('invoice::invoice.label.ref'),
                'sortable' => 'true',
                'roles' => [],
            ],
            [
                'key' => "id",
                'label' => trans('invoice::invoice.label.id'),
                'sortable' => 'true',
                'roles' => [],
            ],
            [
                'key' => "name",
                'label' => trans('invoice::invoice.label.name'),
                'sortable' => 'true',
                'roles' => [],
            ],
            [
                'key' => "status",
                'label' => trans('invoice::invoice.label.status'),
                'sortable' => 'true',
                'roles' => [],
            ],
        ];
        self::$fields = [
                'invoice_number' => [
                "element" => 'numeric',
                "type" => 'numeric',
                "label" => trans('invoice::invoice.label.invoice_number'),
                "placeholder" => trans('invoice::invoice.placeholder.invoice_number'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'restaurant_id' => [
                "element" => 'numeric',
                "type" => 'numeric',
                "label" => trans('invoice::invoice.label.restaurant_id'),
                "placeholder" => trans('invoice::invoice.placeholder.restaurant_id'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'pay_period_type' => [
                "element" => 'radios',
                "type" => 'radios',
                "label" => trans('invoice::invoice.label.pay_period_type'),
                "placeholder" => trans('invoice::invoice.placeholder.pay_period_type'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'debit' => [
                "element" => 'decimal',
                "type" => 'decimal',
                "label" => trans('invoice::invoice.label.debit'),
                "placeholder" => trans('invoice::invoice.placeholder.debit'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'credit' => [
                "element" => 'decimal',
                "type" => 'decimal',
                "label" => trans('invoice::invoice.label.credit'),
                "placeholder" => trans('invoice::invoice.placeholder.credit'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'payment_due' => [
                "element" => 'decimal',
                "type" => 'decimal',
                "label" => trans('invoice::invoice.label.payment_due'),
                "placeholder" => trans('invoice::invoice.placeholder.payment_due'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'pay_period_start' => [
                "element" => 'package::package.formcontrols._date',
                "type" => 'package::package.formcontrols._date',
                "label" => trans('invoice::invoice.label.pay_period_start'),
                "placeholder" => trans('invoice::invoice.placeholder.pay_period_start'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'pay_period_end' => [
                "element" => 'package::package.formcontrols._date',
                "type" => 'package::package.formcontrols._date',
                "label" => trans('invoice::invoice.label.pay_period_end'),
                "placeholder" => trans('invoice::invoice.placeholder.pay_period_end'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'description' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('invoice::invoice.label.description'),
                "placeholder" => trans('invoice::invoice.placeholder.description'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'total_orders' => [
                "element" => 'numeric',
                "type" => 'numeric',
                "label" => trans('invoice::invoice.label.total_orders'),
                "placeholder" => trans('invoice::invoice.placeholder.total_orders'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'cancelled_orders' => [
                "element" => 'numeric',
                "type" => 'numeric',
                "label" => trans('invoice::invoice.label.cancelled_orders'),
                "placeholder" => trans('invoice::invoice.placeholder.cancelled_orders'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'refund_orders' => [
                "element" => 'numeric',
                "type" => 'numeric',
                "label" => trans('invoice::invoice.label.refund_orders'),
                "placeholder" => trans('invoice::invoice.placeholder.refund_orders'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'PRIMARY' => [
                "element" => 'package::package.formcontrols.KEY',
                "type" => 'package::package.formcontrols.KEY',
                "label" => trans('invoice::invoice.label.PRIMARY'),
                "placeholder" => trans('invoice::invoice.placeholder.PRIMARY'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
        ];

        return new static();
    }
}
