<?php

namespace Accounting\Invoice\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Accounting\Invoice\Models\Invoice;

class InvoicePolicy
{

    /**
     * Determine if the given user can view the invoice.
     *
     * @param UserPolicyInterface $authUser
     * @param Invoice $invoice
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Invoice $invoice)
    {
        if ($authUser->canDo('invoice.invoice.view') && $authUser->isAdmin()) {
            return true;
        }

        return $invoice->user_id == user_id() && $invoice->user_type == user_type();
    }

    /**
     * Determine if the given user can create a invoice.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('invoice.invoice.create');
    }

    /**
     * Determine if the given user can update the given invoice.
     *
     * @param UserPolicyInterface $authUser
     * @param Invoice $invoice
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Invoice $invoice)
    {
        if ($authUser->canDo('invoice.invoice.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $invoice->user_id == user_id() && $invoice->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given invoice.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Invoice $invoice)
    {
        return $invoice->user_id == user_id() && $invoice->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given invoice.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Invoice $invoice)
    {
        if ($authUser->canDo('invoice.invoice.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given invoice.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Invoice $invoice)
    {
        if ($authUser->canDo('invoice.invoice.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
