<?php

namespace Accounting\Invoice\Providers;

use Illuminate\Support\ServiceProvider;
use Accounting\Invoice\Invoice;

class InvoiceServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = true;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'invoice');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'invoice');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();

        $this->app->register(\Accounting\Invoice\Providers\AuthServiceProvider::class);
        $this->app->register(\Accounting\Invoice\Providers\RouteServiceProvider::class);
        // $this->app->register(\Accounting\Invoice\Providers\EventServiceProvider::class);
        // $this->app->register(\Accounting\Invoice\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->bind('accounting.invoice', function($app)
        {
            return $this->app->make(Invoice::class);
        });
    }

    /**
     * Register the bindings for the service provider.
     *
     * @return void
     */
    public function registerBindings() {
                // Bind Invoice to repository
        $this->app->bind(
            'Accounting\Invoice\Interfaces\InvoiceRepositoryInterface',
            \Accounting\Invoice\Repositories\Eloquent\InvoiceRepository::class
        );
    }


    /**
     * Merges user's and invoice's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'accounting.invoice'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                \Accounting\Invoice\Commands\Invoice::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['accounting.invoice'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('accounting/invoice.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/invoice')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/invoice')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
