<?php

namespace Accounting\Invoice\Workflow;

use Accounting\Invoice\Models\Invoice;
use Validator;

class InvoiceValidator
{

    /**
     * Determine if the given invoice is valid for complete status.
     *
     * @param Invoice $invoice
     *
     * @return bool / Validator
     */
    public function complete(Invoice $invoice)
    {
        return Validator::make($invoice->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given invoice is valid for verify status.
     *
     * @param Invoice $invoice
     *
     * @return bool / Validator
     */
    public function verify(Invoice $invoice)
    {
        return Validator::make($invoice->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given invoice is valid for approve status.
     *
     * @param Invoice $invoice
     *
     * @return bool / Validator
     */
    public function approve(Invoice $invoice)
    {
        return Validator::make($invoice->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given invoice is valid for publish status.
     *
     * @param Invoice $invoice
     *
     * @return bool / Validator
     */
    public function publish(Invoice $invoice)
    {
        return Validator::make($invoice->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given invoice is valid for archive status.
     *
     * @param Invoice $invoice
     *
     * @return bool / Validator
     */
    public function archive(Invoice $invoice)
    {
        return Validator::make($invoice->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given invoice is valid for unpublish status.
     *
     * @param Invoice $invoice
     *
     * @return bool / Validator
     */
    public function unpublish(Invoice $invoice)
    {
        return Validator::make($invoice->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
